@@ -41,7 +41,7 @@
 #' \code{angle}. Here is an example maze:
 #'
 #' \if{html}{
-#' \figure{para-maze-1.png}{options: width="100\%" alt="Figure: parallelogram maze"}
+#' \figure{para-maze-1.png}{options: style="width: 100\%;" alt="Figure: parallelogram maze"}
 #' }
 #' \if{latex}{
 #' \figure{para-maze-1.png}{options: width=7cm}
@@ -54,7 +54,7 @@
 #' parameter:
 #'
 #' \if{html}{
-#' \figure{para-imbalance-fade-1.png}{options: width="100\%" alt="Figure: parallelogram maze"}
+#' \figure{para-imbalance-fade-1.png}{options: style="width: 100\%;" alt="Figure: parallelogram maze"}
 #' }
 #' \if{latex}{
 #' \figure{para-imbalance-fade-1.png}{options: width=7cm}
@@ -100,7 +100,8 @@
 #' \item{uniform}{The parallelogram maze is built as four
 #' parallelogram mazes with three holey lines and one solid line between them.
 #' Sub-mazes are chosen to be nearly equal in size.}
-#' \item{random}{A method is chosen uniformly at random.}
+#' \item{hilbert}{The parallelogram maze is built as for parallelogram mazes
+#' with a U-shaped connection between them.}
 #' }
 #' @param balance for the \code{two_parallelograms} method, we choose whether
 #' to split on height or width based on a balance condition. The log odds
@@ -110,6 +111,10 @@
 #' Note that balance is positive and large, you tend to generate nearly
 #' uniform splits. When balance is negative and large, you tend to have
 #' imbalanced mazes, and the imbalance propagates.
+#' @param hilbert_balance this is essentially the balance parameter 
+#' but for the \code{hilbert} method, controlling horizontal and vertical
+#' splits.
+#'
 #' @examples
 #'
 #' library(TurtleGraphics)
@@ -167,11 +172,26 @@
 #'     method='two_parallelograms', height_boustro=c(21,3),width_boustro=c(21,3),balance=-0.25,
 #' 		 start_from='corner',draw_boundary=TRUE)
 #' })
+#'
+#' # a Hilbert Curve maze
+#' turtle_init(510,510,mode='clip')
+#' turtle_hide()
+#' turtle_up()
+#' turtle_do({
+#'  turtle_setpos(15,15)
+#'  turtle_setangle(0)
+#'  parallelogram_maze(angle=90,unit_len=10,width=48,height=48,
+#'     method='hilbert',hilbert_balance=3,
+#'     height_boustro=c(10,2),width_boustro=c(10,2),
+#'     boundary_holes=c(1,4),start_from='corner',boundary_hole_locations=c(1,1,1,1),draw_boundary=TRUE)
+#' })
+#'
 #' @export
 #' @importFrom stats runif
 parallelogram_maze <- function(unit_len,height,width=height,angle=90,clockwise=TRUE,
-															 method=c('two_parallelograms','four_parallelograms','uniform','random'),
+															 method=c('two_parallelograms','four_parallelograms','uniform','random','hilbert'),
 															 start_from=c('midpoint','corner'),
+															 hilbert_balance=1,
 															 balance=0,height_boustro=c(1,1),width_boustro=c(1,1),
 															 draw_boundary=FALSE,num_boundary_holes=2,boundary_lines=TRUE,
 															 boundary_holes=NULL,boundary_hole_color=NULL,boundary_hole_locations=NULL,
@@ -187,7 +207,7 @@ parallelogram_maze <- function(unit_len,height,width=height,angle=90,clockwise=T
 	if ((height > 1) && (width > 1)) {
 		my_method <- switch(method,
 												 random={
-													 sample(c('two_parallelograms','four_parallelograms'),1)
+													 sample(c('two_parallelograms','four_parallelograms','hilbert'),1)
 												 },
 												 uniform={ 'four_parallelograms' },
 												 method)
@@ -199,7 +219,7 @@ parallelogram_maze <- function(unit_len,height,width=height,angle=90,clockwise=T
 						 elogo   <- exp(logodds)
 						 spliton <- ifelse(runif(1) <= elogo / (1 + elogo),'height','width')
 						 switch(spliton,
-															 height_boustro=c(1,1),width_boustro=c(1,1),
+										height_boustro=c(1,1),width_boustro=c(1,1),
 										height={
 											midp <- sample.int(size=1,n=(height-1))
 											parallelogram_maze(unit_len=unit_len,height=midp,width=width,angle=angle,clockwise=clockwise,method=method,start_from='corner',
@@ -236,23 +256,23 @@ parallelogram_maze <- function(unit_len,height,width=height,angle=90,clockwise=T
 					 },
 					 four_parallelograms={
 						 bholes <- sample.int(n=4,size=3)
-
-						 if (method == 'uniform') {
+						 if (method=='uniform') {
 							 mid_height <- round((height/2))
 							 mid_width <- round((width/2))
 						 } else {
 							 mid_height <- sample.int(size=1,n=(height-1))
 							 mid_width  <- sample.int(size=1,n=(width-1))
 						 }
-
 						 parallelogram_maze(unit_len=unit_len,height=mid_height,width=mid_width,angle=angle,clockwise=clockwise,method=method,start_from='corner',
 																balance=balance,height_boustro=rev(height_boustro),width_boustro=rev(width_boustro),
 																draw_boundary=TRUE,boundary_lines=2,boundary_holes=1 %in% bholes,
+																hilbert_balance=hilbert_balance,
 																boundary_hole_locations=.rboustro(1,boustro=width_boustro,nsegs=mid_width))
 						 turtle_forward(mid_height*unit_len)
 						 parallelogram_maze(unit_len=unit_len,height=height-mid_height,width=mid_width,angle=angle,clockwise=clockwise,method=method,start_from='corner',
 																balance=balance,height_boustro=rev(height_boustro),width_boustro=rev(width_boustro),
 																draw_boundary=TRUE,boundary_lines=3,boundary_holes=2 %in% bholes,
+																hilbert_balance=hilbert_balance,
 																boundary_hole_locations=.rboustro(1,boustro=height_boustro,nsegs=height-mid_height))
 
 						 .turn_right(angle*multiplier)
@@ -262,17 +282,67 @@ parallelogram_maze <- function(unit_len,height,width=height,angle=90,clockwise=T
 						 parallelogram_maze(unit_len=unit_len,height=height-mid_height,width=width-mid_width,angle=angle,clockwise=clockwise,method=method,start_from='corner',
 																balance=balance,height_boustro=rev(height_boustro),width_boustro=rev(width_boustro),
 																draw_boundary=TRUE,boundary_lines=4,boundary_holes=4 %in% bholes,
+																hilbert_balance=hilbert_balance,
 																boundary_hole_locations=.rboustro(1,boustro=width_boustro,nsegs=width-mid_width))
 						 turtle_backward(mid_height*unit_len)
 						 parallelogram_maze(unit_len=unit_len,height=mid_height,width=width-mid_width,angle=angle,clockwise=clockwise,method=method,start_from='corner',
 																balance=balance,height_boustro=rev(height_boustro),width_boustro=rev(width_boustro),
 																draw_boundary=TRUE,boundary_lines=1,boundary_holes=3 %in% bholes,
+																hilbert_balance=hilbert_balance,
 																boundary_hole_locations=.rboustro(1,boustro=height_boustro,nsegs=mid_height))
 
 						 .turn_right(angle*multiplier)
 						 turtle_backward(mid_width*unit_len)
 						 .turn_left(angle*multiplier)
-					 })
+					 },
+					 hilbert={
+						 # limit the split balance otherwise we get roundoff to zero probs
+						 # and selection complains.
+						 split_bal <- c(1,1) * exp(min(7,hilbert_balance))
+						 mid_height <- .rboustro(1, boustro=split_bal, nsegs=height-1)
+						 mid_width <- .rboustro(1, boustro=split_bal, nsegs=width-1)
+
+						 .turn_right(angle*multiplier)
+						 parallelogram_maze(unit_len=unit_len,height=mid_width,width=mid_height,angle=angle,clockwise=!clockwise,method=method,start_from='corner',
+																balance=balance,height_boustro=(width_boustro),width_boustro=(height_boustro),
+																draw_boundary=TRUE,boundary_lines=3,boundary_holes=3,
+																hilbert_balance=hilbert_balance,
+																boundary_hole_locations=.rboustro(1,boustro=(width_boustro),nsegs=mid_width),
+																end_side=1)
+						 .turn_left(angle*multiplier)
+						 turtle_forward(mid_height*unit_len)
+						 parallelogram_maze(unit_len=unit_len,height=height-mid_height,width=mid_width,angle=angle,clockwise=clockwise,method=method,start_from='corner',
+																balance=balance,height_boustro=(height_boustro),width_boustro=(width_boustro),
+																draw_boundary=TRUE,boundary_lines=3,boundary_holes=3,
+																hilbert_balance=hilbert_balance,
+																boundary_hole_locations=.rboustro(1,boustro=(height_boustro),nsegs=height-mid_height),
+																end_side=1)
+
+						 .turn_right(angle*multiplier)
+						 turtle_forward(mid_width*unit_len)
+						 .turn_left(angle*multiplier)
+						 parallelogram_maze(unit_len=unit_len,height=height-mid_height,width=width-mid_width,angle=angle,clockwise=clockwise,method=method,start_from='corner',
+																balance=balance,height_boustro=(height_boustro),width_boustro=(width_boustro),
+																draw_boundary=TRUE,boundary_lines=4,boundary_holes=4,
+																hilbert_balance=hilbert_balance,
+																boundary_hole_locations=.rboustro(1,boustro=rev(width_boustro),nsegs=width-mid_width),
+																end_side=1)
+						 .turn_right(angle*multiplier)
+						 turtle_forward((width-mid_width)*unit_len)
+						 .turn_right(180)
+
+						 parallelogram_maze(unit_len=unit_len,height=width-mid_width,width=mid_height,angle=angle,clockwise=!clockwise,method=method,start_from='corner',
+																balance=balance,height_boustro=(width_boustro),width_boustro=(height_boustro),
+																draw_boundary=TRUE,boundary_lines=2,boundary_holes=FALSE,
+																hilbert_balance=hilbert_balance,
+																boundary_hole_locations=.rboustro(1,boustro=(height_boustro),nsegs=mid_height),
+																end_side=1)
+						 turtle_forward(width*unit_len)
+						 .turn_left(angle*multiplier)
+						 turtle_forward(mid_height*unit_len)
+						 .turn_left(180)
+					 }
+		)
 	}
 
 	if (draw_boundary) {
